// Copyright (c) Mito
import React, { useState } from 'react';
import Dropdown from './Dropdown';
import DropdownItem from './DropdownItem';
//import { getWidthAsNumber, Width } from './sizes.d';
import SelectDropdownIcon from '../icons/SelectDropdownIcon';
import { classNames } from '../../utils/classNames';
// import css
import '../../../css/elements/Select.css';
import '../../../css/elements/Dropdown.css';
/**
 * The Select component. If open, the select dropdown automatically
 * closes when the user clicks.
 */
const Select = (props) => {
    const [displayDropdown, setDisplayDropdown] = useState(false);
    const width = props.width || 'block';
    const widthClass = `element-width-${width}`;
    const dropdownActiveClass = displayDropdown ? 'select-dropdown-active' : '';
    /*
        Get the value to display, depending on if we just get an array of simple
        string options, or a record with display values as keys, and real values
        as values
    */
    let displayValue;
    if (Array.isArray(props.options)) {
        displayValue = props.value;
    }
    else {
        const optionsRecord = props.options;
        displayValue = optionsRecord[props.value];
    }
    return (React.createElement("div", { className: classNames('select-container', 'text-body-2', widthClass, dropdownActiveClass), onClick: () => void setDisplayDropdown((displayDropdown) => !displayDropdown) },
        React.createElement("p", { className: 'select-text' }, displayValue),
        React.createElement("div", { className: 'select-dropdown-icon-container' },
            React.createElement(SelectDropdownIcon, { purpleOrDarkOrWhite: 'white' })),
        displayDropdown &&
            React.createElement(Dropdown, { closeDropdown: () => setDisplayDropdown(false) },
                Array.isArray(props.options) &&
                    // We have to do some annoying type casting to get this to work properly,
                    // as the compiler has issues reasoning about things.
                    // See more here: https://stackoverflow.com/questions/49510832/how-to-map-over-union-array-type
                    props.options.map((option, idx) => {
                        return (React.createElement(DropdownItem, { key: idx, title: option.toString(), subtext: props.subtexts ? props.subtexts[option] : undefined, 
                            // We cast here as the props.options.map removes the compilers ability
                            // to reason about the fact that string and string | number are mutually
                            // exclusive props, and so the onChange then doesn't type check
                            onClick: () => props.onChange(option) }));
                    }),
                !Array.isArray(props.options) &&
                    Object.entries(props.options).map(([optionKey, optionValue]) => {
                        return (React.createElement(DropdownItem, { key: optionValue, title: optionValue, subtext: props.subtexts ? props.subtexts[optionKey] : undefined, onClick: () => props.onChange(optionKey) }));
                    }))));
};
export default Select;
//# sourceMappingURL=Select.js.map