// Copyright (c) Mito
import React, { useState, useRef, useEffect } from 'react';
import { ModalEnum } from './modals';
import BlueMitoFolk from '../icons/mitofolks/BlueMitoFolk';
import PinkMitoFolk from '../icons/mitofolks/PinkMitoFolk';
import YellowMitoFolk from '../icons/mitofolks/YellowMitoFolk';
import '../../../css/signup-modal.css';
import TextButton from '../elements/TextButton';
import Input from '../elements/Input';
/*
    This file contains all the screens used in the signup modal. As these
    are only used in this one file, we keep them together for cleanlyness.
*/
/* Step one requires an email input */
const StepOne = (props) => {
    // Make sure the input is focused on, as we want the experience of sign up
    // to be as fluid as possible, and the autofocus does not work for this 
    // input element, for some reason
    const emailInputRef = useRef(null);
    useEffect(() => {
        var _a;
        (_a = emailInputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    });
    const onSubmit = async (e) => {
        e.preventDefault();
        await props.mitoAPI.sendSignUp(props.email);
        props.next();
    };
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("div", null,
            React.createElement("h1", { className: 'mt-0' }, "Sign Up for Mito"),
            React.createElement("p", { className: 'signup-modal-text' }, "We\u2019ll send you periodic product updates and welcome any feedback. And no spam. Duh.")),
        React.createElement("form", { className: 'signup-modal-email-form', onSubmit: onSubmit },
            React.createElement("h3", { className: 'mb-20px' }, "Your Email"),
            React.createElement(Input, { value: props.email, onChange: (event) => { props.setEmail(event.target.value); }, type: 'email', width: 'large', placeholder: 'example@gmail.com', ref: emailInputRef, required: true, autoFocus: true }),
            React.createElement("div", { className: 'mt-20px' },
                React.createElement(TextButton, { variant: 'dark', width: 'large', type: 'submit' }, "Sign Up")))));
};
/* Step one requires the user to read the privacy policy */
const StepTwo = (props) => {
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("div", null,
            React.createElement("h1", { className: 'mt-0' }, "Mito is Built for Privacy"),
            React.createElement("p", { className: 'signup-modal-text' },
                "We make sure none of your private data leaves your computer. Read our CCPA compliant privacy policy ",
                React.createElement("a", { href: 'https://privacy.trymito.io/privacy-policy', target: '_blank', rel: "noreferrer" },
                    React.createElement("u", null, "here")),
                ".")),
        React.createElement("div", { className: 'signup-modal-buttons mt-10px' },
            React.createElement(TextButton, { variant: 'light', width: 'small', onClick: props.back }, "Back"),
            React.createElement(TextButton, { variant: 'dark', width: 'small', onClick: props.next, autoFocus: true }, "Accept"))));
};
/* Step three asks the user want they want to use Mito for */
const StepThree = (props) => {
    const FirstQuestion = 'Where did you hear about Mito?';
    const FirstPlaceholder = 'The Borking Dog channel on YouTube';
    const SecondQuestion = 'What is your main code editor for Python data analysis?';
    const SecondPlaceholder = undefined;
    const onSubmit = async (e) => {
        e.preventDefault();
        // Set the feedback on what the user intends to do
        await props.mitoAPI.sendFeedback({
            [FirstQuestion]: props.firstResponse,
            [SecondQuestion]: props.secondResponse
        });
        // Advance to the next step
        props.next();
    };
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("form", { onSubmit: onSubmit },
            React.createElement("div", null,
                React.createElement("label", null,
                    React.createElement("h3", { className: 'mt-0 mb-10px' }, FirstQuestion)),
                React.createElement(Input, { value: props.firstResponse, onChange: (e) => { props.setFirstResponse(e.target.value); }, placeholder: FirstPlaceholder, required: true, autoFocus: true }),
                React.createElement("label", null,
                    React.createElement("h3", { className: 'mt-25px mb-10px' }, SecondQuestion)),
                React.createElement(Input, { value: props.secondResponse, onChange: (e) => { props.setSecondResponse(e.target.value); }, placeholder: SecondPlaceholder, required: true })),
            React.createElement("div", { className: 'mt-50px signup-modal-buttons' },
                React.createElement(TextButton, { variant: 'light', width: 'small', 
                    /* For some reason, we have to make this a button so it doesn't get auto clicked */
                    type: 'button', onClick: props.back }, "Back"),
                React.createElement(TextButton, { variant: 'dark', width: 'small', type: 'submit' }, "Finish")))));
};
/*
    First signup modal, which collects the users email, shows them the privacy policy,
    and then asks them what they want to do with the tool.
*/
const SignupModal = (props) => {
    const [step, setStep] = useState(1);
    const [email, setEmail] = useState('');
    // Store the first and second response here, so if they use the back button, their answers are stored
    const [firstResponse, setFirstResponse] = useState('');
    const [secondResponse, setSecondResponse] = useState('');
    const next = () => {
        if (step + 1 > 3) {
            props.setModal({ type: ModalEnum.None });
            void props.mitoAPI.sendLogMessage('finished_signup');
        }
        else {
            const newStep = Math.min(step + 1, 3);
            setStep(newStep);
            void props.mitoAPI.sendLogMessage('switched_signup_step', {
                'old_signup_step': step,
                'new_signup_step': newStep
            });
        }
    };
    const back = () => {
        const newStep = Math.max(step - 1, 0);
        setStep(newStep);
        void props.mitoAPI.sendLogMessage('switched_signup_step', {
            'old_signup_step': step,
            'new_signup_step': newStep
        });
    };
    // Background colors of the different steps right column
    const backgroundColors = {
        1: '#FFEBEB',
        2: '#FFDAAE',
        3: '#F0C5BB',
    };
    return (React.createElement("div", { className: 'overlay' },
        React.createElement("div", { className: 'signup-modal-container' },
            React.createElement("div", { className: 'signup-modal-left-column-container' },
                step === 1 &&
                    React.createElement(StepOne, { next: next, email: email, setEmail: setEmail, mitoAPI: props.mitoAPI }),
                step === 2 &&
                    React.createElement(StepTwo, { next: next, back: back }),
                step === 3 &&
                    React.createElement(StepThree, { next: next, back: back, firstResponse: firstResponse, setFirstResponse: setFirstResponse, secondResponse: secondResponse, setSecondResponse: setSecondResponse, mitoAPI: props.mitoAPI })),
            React.createElement("div", { className: 'signup-modal-right-column-container', style: { backgroundColor: backgroundColors[step] } },
                step === 1 &&
                    React.createElement(BlueMitoFolk, null),
                step === 2 &&
                    React.createElement(YellowMitoFolk, null),
                step === 3 &&
                    React.createElement(PinkMitoFolk, null)))));
};
export default SignupModal;
//# sourceMappingURL=SignupModal.js.map