// Copyright (c) Mito
import React, { useState } from 'react';
import { TaskpaneType } from '../taskpanes';
// Import the content this displays
import FunctionDocumentationContent from './FunctionDocumentationContent';
import DocumentationListContent from './DocumentationListContent';
import BasicExampleContainer from './BasicExampleContainer';
import DocumentationBackArrowIcon from '../../icons/DocumentationBackArrowIcon';
/*
    This object holds the documentation taskpane, as well as the
    state currently displayed by the documentation.

    This can either be:
    1. A list of all content (when selectedDocumentation is undefined)
    2. Documentation for a specific function (when typeof selectedDocumentation is FunctionDocumentation)
    3. Documentation for some basic example (when typeof selectedDocumentation is BasicDocumentation)
*/
const DocumentationTaskpane = (props) => {
    const [selectedDocumentation, setSelectedDocumentation] = useState(undefined);
    const getSelectedDocumentationContent = () => {
        // Returns the selected documentation, which is either nothing (the list of all documentation), 
        // a basic example, or a specific function.
        if (selectedDocumentation === undefined) {
            return (React.createElement(DocumentationListContent, { setCurrOpenTaskpane: props.setCurrOpenTaskpane, setSelectedDocumentation: setSelectedDocumentation, mitoAPI: props.mitoAPI }));
        }
        else if (selectedDocumentation.kind === 'basic') {
            return React.createElement(BasicExampleContainer, { basicExampleName: selectedDocumentation.basicExampleName });
        }
        else if (selectedDocumentation.kind === 'function') {
            return (React.createElement(FunctionDocumentationContent, { function: selectedDocumentation.function }));
        }
    };
    return (React.createElement("div", { className: 'default-taskpane-div' },
        React.createElement("div", { className: 'default-taskpane-header-div' },
            selectedDocumentation === undefined &&
                React.createElement("div", { className: 'text-header-2 text-overflow-hide' }, "Documentation"),
            selectedDocumentation !== undefined &&
                React.createElement("div", { className: 'documentation-taskpane-header-back-and-title' },
                    React.createElement("div", { className: 'documentation-taskpane-header-back', onClick: () => { setSelectedDocumentation(undefined); } },
                        React.createElement(DocumentationBackArrowIcon, null)),
                    React.createElement("div", { className: 'text-header-2 text-overflow-hide' }, "Documentation")),
            React.createElement("div", { className: 'default-taskpane-header-exit-button-div', onClick: () => props.setCurrOpenTaskpane({ type: TaskpaneType.NONE }) },
                React.createElement("svg", { width: "18", height: "18", viewBox: "0 0 13 13", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
                    React.createElement("line", { x1: "0.707107", y1: "1.29289", x2: "11.3136", y2: "11.8994", stroke: "#343434", strokeWidth: "2" }),
                    React.createElement("line", { x1: "0.7072", y1: "11.8995", x2: "11.3137", y2: "1.29297", stroke: "#343434", strokeWidth: "2" })))),
        React.createElement("div", { className: 'default-taskpane-body-div' }, getSelectedDocumentationContent())));
};
export default DocumentationTaskpane;
//# sourceMappingURL=DocumentationTaskpane.js.map