// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
import React, { useEffect, useState } from 'react';
import DefaultTaskpane from '../DefaultTaskpane';
import TextButton from '../../elements/TextButton';
/*
    A taskpane that allows a user to download their current sheet.

    It does this by:
    1. Getting a string representation of the sheet through the api
    2. Encoding that as a file
    3. Allowing the user to download that file

    To see more about this process, read documentation here:
    https://blog.logrocket.com/programmatic-file-downloads-in-the-browser-9a5186298d5c/
*/
const DownloadTaskpane = (props) => {
    const [dataframeCSV, setDataframeCSV] = useState('');
    const loadDataframeCSV = async () => {
        const loadedDataframeCSV = await props.mitoAPI.getDataframeAsCSV(props.selectedSheetIndex);
        setDataframeCSV(loadedDataframeCSV);
    };
    // Async load in the data from the mitoAPI
    useEffect(() => {
        setDataframeCSV('');
        void loadDataframeCSV();
    }, [props.selectedSheetIndex]);
    const onDownload = () => {
        void props.mitoAPI.sendLogMessage('button_download_log_event', {
            sheet_index: props.selectedSheetIndex,
            df_name: props.dfName
        });
    };
    return (React.createElement(DefaultTaskpane, { header: 'Download', setCurrOpenTaskpane: props.setCurrOpenTaskpane, taskpaneBody: React.createElement(React.Fragment, null,
            dataframeCSV === '' &&
                React.createElement("p", { className: 'text-body-1 text-overflow-wrap' }, "Give us a few seconds to prepare your data for download..."),
            React.createElement(TextButton, { variant: 'dark', width: 'block', disabled: dataframeCSV === '', href: URL.createObjectURL(new Blob([dataframeCSV], { type: 'text/csv' })), download: props.dfName + '.csv', onClick: onDownload }, `Download ${props.dfName}`)) }));
};
export default DownloadTaskpane;
//# sourceMappingURL=DownloadTaskpane.js.map